@@ -14,7 +14,7 @@ from kameleoon.client_configuration import KameleoonClientConfiguration
 
 from kameleoon.data import Conversion, get_nonce, Data
 from kameleoon.defaults import DEFAULT_BLOCKING, DEFAULT_CONFIGURATION_PATH, DEFAULT_TIMEOUT_MILLISECONDS, \
-    DEFAULT_VISITOR_DATA_MAXIMUM_SIZE, DEFAULT_CONFIGURATION_UPDATE_INTERVAL
+    DEFAULT_TIMEOUT_SECONDS, DEFAULT_VISITOR_DATA_MAXIMUM_SIZE, DEFAULT_CONFIGURATION_UPDATE_INTERVAL
 from kameleoon.version import __version__ as kameleoon_python_version
 
 from kameleoon.exceptions import ConfigurationNotFoundException, CredentialsNotFoundException, \
@@ -113,7 +113,7 @@ class KameleoonClient:
                           filters: Optional[List[Dict[str, Union[str, List[Union[str, int]]]]]] = None,
                           payload=None,
                           method: Literal['post', 'get'] = 'post',
-                          timeout: Optional[int] = None) -> Optional[Any]:
+                          timeout: Optional[float] = DEFAULT_TIMEOUT_SECONDS) -> Optional[Any]:
         """
         :param url: API URL
         :type url: str
@@ -160,7 +160,7 @@ class KameleoonClient:
     def _fetch_all(self,
                    url: str, headers: Dict[str, str],
                    filters=None, payload=None,
-                   timeout=None):
+                   timeout=DEFAULT_TIMEOUT_SECONDS):
         """
         Getting data from multiple data pages
         :param url: API URL
@@ -195,7 +195,7 @@ class KameleoonClient:
 
     def _fetch_all_graphql(self,
                            url: str, data: str, headers: Dict[str, str],
-                           timeout=None):
+                           timeout=DEFAULT_TIMEOUT_SECONDS):
         """
         Getting data from multiple data pages
         :param url: API URL
@@ -355,7 +355,8 @@ class KameleoonClient:
             variation_id = self.make_sync_request(f"{self.tracking_base_url}{path}",
                                                   method='post',
                                                   payload=("\n".join(body or '').encode("UTF-8")),
-                                                  headers=self._get_headers())
+                                                  headers=self._get_headers(),
+                                                  timeout=timeout)
             if not variation_id or isinstance(variation_id, Response):
                 self.logger.error("Failed to trigger experiment: %s variation_id %s", experiment_id, variation_id)
                 raise ExperimentConfigurationNotFound(message=str(experiment_id))
@@ -619,7 +620,7 @@ class KameleoonClient:
         feature_flag = self.get_feature_flag(feature_key)
         data_not_sent = self._data_not_sent(visitor_code)
         if self.blocking:
-            connexion_options = {"connect_timeout": int(timeout / 1000.0)}
+            connexion_options = {"connect_timeout": float(timeout / 1000.0)}
             try:
                 body: Union[List[str], str] = [
                     data_instance.obtain_full_post_text_line() for data_instance in  # type: ignore
@@ -745,7 +746,7 @@ class KameleoonClient:
 
     def retrieve_data_from_remote_source(self,
                                          key: str,
-                                         timeout: Optional[int] = DEFAULT_TIMEOUT_MILLISECONDS) -> Optional[Any]:
+                                         timeout: Optional[float] = DEFAULT_TIMEOUT_SECONDS) -> Optional[Any]:
         """
         The retrieved_data_from_remote_source method allows you to retrieve data (according to a key passed as
         argument)stored on a remote Kameleoon server. Usually data will be stored on our remote servers
@@ -804,13 +805,15 @@ class KameleoonClient:
         auth_resp = self._obtain_access_token()
         if auth_resp:
             self.access_token = auth_resp['access_token']
-        self.logger.debug('Scheduled job to fetch configuration graphQL is starting.')
-        self.obtain_experiments_graphql(self.site_code)
-        self.obtain_feature_flags_graphql(self.site_code, self.environment)
-        if self.timer is not None:
-            self.timer.cancel()
-
-        self._add_fetch_configuration_after_delay()
+            self.logger.debug('Scheduled job to fetch configuration graphQL is starting.')
+            self.obtain_experiments_graphql(self.site_code)
+            self.obtain_feature_flags_graphql(self.site_code, self.environment)
+            if self.timer is not None:
+                self.timer.cancel()
+            self._add_fetch_configuration_after_delay()
+        else:
+            self.logger.error('The access token could not be obtained. \
+            Please check credentials \'client_id\' and \'client_secret\'')
 
     def _add_fetch_configuration_after_delay(self) -> None:
         """
